﻿using Microsoft.Phone.Controls;
using Microsoft.Phone.Tasks;
using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using XboxMusicLibrary;
using XboxMusicLibrary.Models;
using XboxMusicLibrary.Settings;

namespace XboxMusicDemo
{
    public partial class ArtistPage : PhoneApplicationPage
    {
        MusicHelper helper = null;
        Music music = null;
        Artist artist = null;
        string Id = "";

        Extras[] extras = new Extras[] { Extras.Albums, Extras.TopTracks };

        public ArtistPage()
        {
            InitializeComponent();
            helper = new MusicHelper();
            this.Loaded += ArtistPage_Loaded;
        }

        async void ArtistPage_Loaded(object sender, System.Windows.RoutedEventArgs e)
        {
            LayoutProgress.Visibility = Visibility.Visible;

            string token = await helper.GetAccessToken(App.ClientId, App.ClientSecret);

            string[] namespaceids = new string[] { Id };
            music = await helper.LookupMediaCatalog(token, namespaceids,  extras, new Culture("fr","FR"));

            this.Dispatcher.BeginInvoke(() =>
            {
                artist = music.Artists.Items[0];
                this.DataContext = artist;
            });

            LayoutProgress.Visibility = Visibility.Collapsed;
        }

        private void AlbumsList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            // If selected item is null (no selection) do nothing
            if (AlbumsList.SelectedItem == null)
                return;

            // Navigate to the new page
            NavigationService.Navigate(new Uri("/TracksPage.xaml?selectedItem=" + (AlbumsList.SelectedItem as Album).Id, UriKind.Relative));

            // Reset selected item to null (no selection)
            AlbumsList.SelectedItem = null;
        }

        private void TracksList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            // If selected item is null (no selection) do nothing
            if (TracksList.SelectedItem == null)
                return;

            Track track = TracksList.SelectedItem as Track;
            // Navigate to the Xbox Music application
            WebBrowserTask webBrowserTask = new WebBrowserTask();
            webBrowserTask.Uri = new Uri(track.DeepLinkPlay, UriKind.Absolute);
            webBrowserTask.Show();

            // Reset selected item to null (no selection)
            TracksList.SelectedItem = null;
        }

        // When page is navigated to set data context to selected item in list
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            NavigationContext.QueryString.TryGetValue("selectedItem", out Id);
        }

        private async void AlbumsList_ItemRealized(object sender, ItemRealizationEventArgs e)
        {
            LayoutProgress.Visibility = Visibility.Visible;

            int offset = 25;
            if (AlbumsList.ItemsSource != null && AlbumsList.ItemsSource.Count >= offset)
            {
                if (e.ItemKind == LongListSelectorItemKind.Item)
                {
                    if ((e.Container.Content as Album).Equals(AlbumsList.ItemsSource[AlbumsList.ItemsSource.Count - offset]))
                    {
                        // Refresh token (in case of expiration)
                        string token = await helper.GetAccessToken(App.ClientId, App.ClientSecret);
                        if (artist != null)
                        {
                            string[] namespaceids = new string[] { Id };
                            string continuationToken = artist.Albums.ContinuationToken;
                            
                            Music result = await helper.LoadNext(token, continuationToken, namespaceids);
                            foreach (Album item in result.Artists.Items[0].Albums.Items)
                            {
                                artist.Albums.Items.Add(item);
                            }
                        }
                    }
                }
            }

            LayoutProgress.Visibility = Visibility.Collapsed;
        }

        private async void TracksList_ItemRealized(object sender, ItemRealizationEventArgs e)
        {
            LayoutProgress.Visibility = Visibility.Visible;

            int offset = 25;
            if (TracksList.ItemsSource != null && TracksList.ItemsSource.Count >= offset)
            {
                if (e.ItemKind == LongListSelectorItemKind.Item)
                {
                    if ((e.Container.Content as Track).Equals(TracksList.ItemsSource[TracksList.ItemsSource.Count - offset]))
                    {
                        // Refresh token (in case of expiration)
                        string token = await helper.GetAccessToken(App.ClientId, App.ClientSecret);
                        if (artist != null)
                        {
                            string[] namespaceids = new string[] { Id };
                            string continuationToken = artist.TopTracks.ContinuationToken;

                            Music result = await helper.LoadNext(token, continuationToken, namespaceids);
                            foreach (Track item in result.Artists.Items[0].TopTracks.Items)
                            {
                                artist.TopTracks.Items.Add(item);
                            }
                        }
                        
                    }
                }
            }

            LayoutProgress.Visibility = Visibility.Collapsed;
        }
    }
}