﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using XboxMusicDemo.Resources;
using XboxMusicLibrary;
using XboxMusicLibrary.Models;
using System.Windows.Controls.Primitives;
using XboxMusicControls;
using Microsoft.Phone.Tasks;
using System.Diagnostics;
using XboxMusicLibrary.Settings;

namespace XboxMusicDemo
{
    public partial class MainPage : PhoneApplicationPage
    {
        Music music = null;
        MusicHelper helper = null;

        // Constructor
        public MainPage()
        {
            InitializeComponent();

            helper = new MusicHelper();
            helper.Failed += helper_Failed;
            this.Loaded += MainPage_Loaded;
        }

        void helper_Failed(object sender, ErrorEventArgs e)
        {
            string message = e.Message;
            Debug.WriteLine(message);
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            SearchInCatalog(App.Keywords);
        }

        private void ArtistsList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            // If selected item is null (no selection) do nothing
            if (ArtistsList.SelectedItem == null)
                return;

            // Navigate to the new page
            NavigationService.Navigate(new Uri("/ArtistPage.xaml?selectedItem=" + (ArtistsList.SelectedItem as Artist).Id, UriKind.Relative));

            // Reset selected item to null (no selection)
            ArtistsList.SelectedItem = null;
        }

        private void AlbumsList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            // If selected item is null (no selection) do nothing
            if (AlbumsList.SelectedItem == null)
                return;

            // Navigate to the new page
            NavigationService.Navigate(new Uri("/TracksPage.xaml?selectedItem=" + (AlbumsList.SelectedItem as Album).Id, UriKind.Relative));

            // Reset selected item to null (no selection)
            AlbumsList.SelectedItem = null;
        }

        private void TracksList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            // If selected item is null (no selection) do nothing
            if (TracksList.SelectedItem == null)
                return;

            Track track = TracksList.SelectedItem as Track;
            // Navigate to the Xbox Music application
            WebBrowserTask webBrowserTask = new WebBrowserTask();
            webBrowserTask.Uri = new Uri(track.DeepLinkPlay, UriKind.Absolute);
            webBrowserTask.Show();

            // Reset selected item to null (no selection)
            TracksList.SelectedItem = null;
        }

        private async void SearchInCatalog(string keywords)
        {
            LayoutProgress.Visibility = Visibility.Visible;

            string token = await helper.GetAccessToken(App.ClientId, App.ClientSecret);
            Filters[] filters = new Filters[] { Filters.Music };

            music = await helper.SearchMediaCatalog(token, keywords, 25, filters, new Culture("fr", "FR"));

            this.Dispatcher.BeginInvoke(() =>
            {
                this.DataContext = music;
            });

            LayoutProgress.Visibility = Visibility.Collapsed;
        }

        private void SearchIconButton_Click(object sender, EventArgs e)
        {
            Popup popup = new Popup();
            popup.VerticalOffset = 24;
            InputPrompt promptControl = new InputPrompt();
            popup.Child = promptControl;

            popup.Closed += (s1, s2) =>
            {
                string keywords = promptControl.Keywords;
                if (!string.IsNullOrEmpty(keywords))
                {
                    SearchInCatalog(keywords);
                    App.Keywords = keywords;
                }
            };

            popup.IsOpen = true;
        }

        private async void AlbumsList_ItemRealized(object sender, ItemRealizationEventArgs e)
        {
            LayoutProgress.Visibility = Visibility.Visible;

            int offset = 25;
            if (AlbumsList.ItemsSource != null && AlbumsList.ItemsSource.Count >= offset)
            {
                if (e.ItemKind == LongListSelectorItemKind.Item)
                {
                    if ((e.Container.Content as Album).Equals(AlbumsList.ItemsSource[AlbumsList.ItemsSource.Count - offset]))
                    {
                        // Refresh token (in case of expiration)
                        string token = await helper.GetAccessToken(App.ClientId, App.ClientSecret);
                        string continuationToken = music.Albums.ContinuationToken;

                        Music result = await helper.LoadNext(token, continuationToken);
                        foreach (Album item in result.Albums.Items)
                        {
                            music.Albums.Items.Add(item);
                        }
                    }
                }
            }

            LayoutProgress.Visibility = Visibility.Collapsed;
        }

        private async void TracksList_ItemRealized(object sender, ItemRealizationEventArgs e)
        {
            LayoutProgress.Visibility = Visibility.Visible;

            int offset = 25;
            if (TracksList.ItemsSource != null && TracksList.ItemsSource.Count >= offset)
            {
                if (e.ItemKind == LongListSelectorItemKind.Item)
                {
                    if ((e.Container.Content as Track).Equals(TracksList.ItemsSource[TracksList.ItemsSource.Count - offset]))
                    {
                        // Refresh token (in case of expiration)
                        string token = await helper.GetAccessToken(App.ClientId, App.ClientSecret);
                        string continuationToken = music.Tracks.ContinuationToken;

                        Music result = await helper.LoadNext(token, continuationToken);
                        foreach (Track item in result.Tracks.Items)
                        {
                            music.Tracks.Items.Add(item);
                        }
                    }
                }
            }

            LayoutProgress.Visibility = Visibility.Collapsed;
        }
    }
}