﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using XboxMusicLibrary.Models;
using Microsoft.Phone.Tasks;
using XboxMusicLibrary;
using XboxMusicLibrary.Settings;

namespace XboxMusicDemo
{
    public partial class TracksPage : PhoneApplicationPage
    {
        MusicHelper helper = null;
        string Id = "";

        public TracksPage()
        {
            InitializeComponent();
            helper = new MusicHelper();

            this.Loaded += TracksPage_Loaded;
        }

        async void TracksPage_Loaded(object sender, RoutedEventArgs e)
        {
            LayoutProgress.Visibility = System.Windows.Visibility.Visible;

            string token = await helper.GetAccessToken(App.ClientId, App.ClientSecret);

            string[] namespaceids = new string[] { Id };
            Extras[] extras = new Extras[] { Extras.Tracks };

            Music music = await helper.LookupMediaCatalog(token, namespaceids, extras, new Culture("fr", "FR"));

            List<AlphaKeyGroup<Track>> DataSource = AlphaKeyGroup<Track>.CreateGroups(music.Albums.Items[0].Tracks.Items, System.Threading.Thread.CurrentThread.CurrentUICulture,
                (Track s) => { return s.Name; }, true);

            this.Dispatcher.BeginInvoke(() =>
            {
                this.DataContext = music.Albums.Items[0];
                TracksList.ItemsSource = DataSource;
            });

            LayoutProgress.Visibility = System.Windows.Visibility.Collapsed;
        }

        private void TracksList_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            // If selected item is null (no selection) do nothing
            if (TracksList.SelectedItem == null)
                return;

            Track track = TracksList.SelectedItem as Track;
            // Navigate to the Xbox Music application
            WebBrowserTask webBrowserTask = new WebBrowserTask();
            webBrowserTask.Uri = new Uri(track.DeepLinkPlay, UriKind.Absolute);
            webBrowserTask.Show();

            // Reset selected item to null (no selection)
            TracksList.SelectedItem = null;
        }

        // When page is navigated to set data context to selected item in list
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            NavigationContext.QueryString.TryGetValue("selectedItem", out Id);
        }
    }
}